@@ -82,12 +82,12 @@ typedef struct {
 	 */
 	void (*menu_item_activated)	(BonoboUIHandler *uih, char *path, void *item_data);
 	void (*menu_item_removed)	(BonoboUIHandler *uih, char *path, void *item_data);
-	void (*menu_item_overriden)	(BonoboUIHandler *uih, char *path, void *item_data);
+	void (*menu_item_overridden)	(BonoboUIHandler *uih, char *path, void *item_data);
 	void (*menu_item_reinstated)	(BonoboUIHandler *uih, char *path, void *item_data);
 
 	void (*toolbar_item_activated)	(BonoboUIHandler *uih, char *path, void *item_data);
 	void (*toolbar_item_removed)	(BonoboUIHandler *uih, char *path, void *item_data);
-	void (*toolbar_item_overriden)	(BonoboUIHandler *uih, char *path, void *item_data);
+	void (*toolbar_item_overridden)	(BonoboUIHandler *uih, char *path, void *item_data);
 	void (*toolbar_item_reinstated)	(BonoboUIHandler *uih, char *path, void *item_data);
 } BonoboUIHandlerClass;
 
@@ -343,11 +343,6 @@ void				 bonobo_ui_handler_create_toolbar	(BonoboUIHandler *uih, const char *nam
 void				 bonobo_ui_handler_remove_toolbar	(BonoboUIHandler *uih, const char *name);
 GList				*bonobo_ui_handler_get_toolbar_list	(BonoboUIHandler *uih);
 
-void				 bonobo_ui_handler_toolbar_set_orientation (BonoboUIHandler *uih, const char *path,
-									   GtkOrientation orientation);
-GtkOrientation			 bonobo_ui_handler_toolbar_get_orientation (BonoboUIHandler *uih, const char *path);
-
-
 
 void				 bonobo_ui_handler_toolbar_new		(BonoboUIHandler *uih, const char *path,
 									 BonoboUIHandlerToolbarItemType type,
