@@ -496,14 +496,17 @@ toolbar_toplevel_item_remove_widgets (BonoboUIHandler *uih, const char *path)
 	 */
 	found = g_hash_table_lookup_extended (uih->top->path_to_toolbar_item_widget, path,
 					      (gpointer *) &orig_key, (gpointer *) &toolbar_item_widget);
-	g_hash_table_remove (uih->top->path_to_toolbar_item_widget, path);
-	g_free (orig_key);
 
-	/*
-	 * Destroy the widget.
-	 */
-	if (found && toolbar_item_widget != NULL)
-		gtk_widget_destroy (toolbar_item_widget);
+	if (found) {
+		g_hash_table_remove (uih->top->path_to_toolbar_item_widget, path);
+		g_free (orig_key);
+
+		/*
+		 * Destroy the widget.
+		 */
+		if (toolbar_item_widget != NULL)
+			gtk_widget_destroy (toolbar_item_widget);
+	}
 }
 
 static void
@@ -888,6 +891,11 @@ bonobo_ui_handler_set_toolbar (BonoboUIHandler *uih, const char *name,
 
 	toolbar_toplevel_toolbar_check_override (uih, name);
 
+	/*
+	 * Store it in the widget hash table.
+	 */
+	g_hash_table_insert (uih->top->name_to_toolbar_widget, g_strdup (name), toolbar);
+
 	toolbar_toplevel_toolbar_store_data (
 		uih, name, bonobo_object_corba_objref (BONOBO_OBJECT (uih)));
 }
@@ -1127,7 +1135,7 @@ toolbar_toplevel_item_create_widgets (BonoboUIHandler *uih,
 
 		gtk_widget_show (toolbar_item);
 
-		if (internal->item->pos > 0)
+		if (internal->item->pos >= 0)
 			gtk_toolbar_insert_widget (GTK_TOOLBAR (toolbar),
 						   toolbar_item,
 						   internal->item->hint, NULL,
@@ -1140,6 +1148,11 @@ toolbar_toplevel_item_create_widgets (BonoboUIHandler *uih,
 		break;
 
 	case BONOBO_UI_HANDLER_TOOLBAR_SEPARATOR:
+		/*
+		 * No toolbar_item in this case because GtkToolbar doesn't create a widget.
+		 * FIXME: This separator cannot be removed; attempting to do so has no
+		 * adverse effects but no positive ones either.
+		 */
 		gtk_toolbar_insert_space (GTK_TOOLBAR (toolbar), internal->item->pos);
 		break;
 
@@ -1150,7 +1163,7 @@ toolbar_toplevel_item_create_widgets (BonoboUIHandler *uih,
 				toolbar, internal->item->pixmap_type, internal->item->pixmap_data);
 
 
-		if (internal->item->pos > 0)
+		if (internal->item->pos >= 0)
 			toolbar_item = gtk_toolbar_insert_element (GTK_TOOLBAR (toolbar),
 								   toolbar_type_to_gtk_type (internal->item->type),
 								   NULL, internal->item->label, internal->item->hint,
@@ -1169,7 +1182,7 @@ toolbar_toplevel_item_create_widgets (BonoboUIHandler *uih,
 
 	case BONOBO_UI_HANDLER_TOOLBAR_TOGGLEITEM:
 
-		if (internal->item->pos > 0)
+		if (internal->item->pos >= 0)
 			toolbar_item = gtk_toolbar_insert_element (GTK_TOOLBAR (toolbar),
 								   toolbar_type_to_gtk_type (internal->item->type),
 								   NULL, internal->item->label, internal->item->hint,
@@ -1197,9 +1210,16 @@ toolbar_toplevel_item_create_widgets (BonoboUIHandler *uih,
 		return;
 	}
 
-	/* FIXME: Connect to signals and gtk_widget_add_accelerator */
-
-	g_hash_table_insert (uih->top->path_to_toolbar_item_widget, g_strdup (internal->item->path), toolbar_item);
+	/* 
+	 * toolbar_item is legitimately (?) NULL in at least the BONOBO_UI_HANDLER_TOOLBAR_SEPARATOR case. 
+	 * Perhaps we should insert the NULL into the hash table anyway as a marker for the separator,
+	 * so that later we can actually remove the separator.
+	 */
+	if (toolbar_item != NULL) {
+		/* FIXME: Connect to signals and gtk_widget_add_accelerator */
+	        gtk_object_ref (GTK_OBJECT (toolbar_item));
+		g_hash_table_insert (uih->top->path_to_toolbar_item_widget, g_strdup (internal->item->path), toolbar_item);
+	}
 }
 
 static void
@@ -1267,7 +1287,6 @@ toolbar_toplevel_item_store_data (BonoboUIHandler *uih, Bonobo_UIHandler uih_cor
 	internal->item = toolbar_copy_item (item);
 	internal->uih = uih;
 	internal->sensitive = TRUE;
-	internal->active = FALSE;
 
 	CORBA_exception_init (&ev);
 	internal->uih_corba = CORBA_Object_duplicate (uih_corba, &ev);
@@ -1303,9 +1322,11 @@ toolbar_toplevel_item_set_sensitivity_internal (BonoboUIHandler *uih, ToolbarIte
 		return;
 
 	toolbar_widget = toolbar_toplevel_item_get_widget (uih, internal->item->path);
-	g_return_if_fail (toolbar_widget != NULL);
 
-	gtk_widget_set_sensitive (toolbar_widget, sensitive);
+	if (toolbar_widget != NULL) {
+		/* toolbar_widget is legitimately (?) NULL in at least the BONOBO_UI_HANDLER_TOOLBAR_SEPARATOR case. */ 
+		gtk_widget_set_sensitive (toolbar_widget, sensitive);
+	}
 }
 
 static void
@@ -1372,6 +1393,29 @@ static void
 toolbar_toplevel_item_set_toggle_state_internal (BonoboUIHandler *uih, ToolbarItemInternal *internal,
 						 gboolean active)
 {
+	GtkWidget *toolbar_widget;
+
+	if (! toolbar_toplevel_item_is_head (uih, internal))
+		return;
+
+	toolbar_widget = toolbar_toplevel_item_get_widget (uih, internal->item->path);
+	g_return_if_fail (toolbar_widget != NULL);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toolbar_widget), active);
+}
+
+static gboolean
+toolbar_toplevel_item_get_toggle_state_internal (BonoboUIHandler *uih, ToolbarItemInternal *internal)
+{
+	GtkWidget *toolbar_widget;
+
+	if (! toolbar_toplevel_item_is_head (uih, internal))
+		return FALSE;
+
+	toolbar_widget = toolbar_toplevel_item_get_widget (uih, internal->item->path);
+	g_return_val_if_fail (toolbar_widget != NULL, FALSE);
+
+	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toolbar_widget));
 }
 
 static void
@@ -1412,9 +1456,9 @@ toolbar_toplevel_create_item (BonoboUIHandler *uih, const char *parent_path,
 	 * Set its active state.
 	 */
 	if (internal->item->type == BONOBO_UI_HANDLER_TOOLBAR_TOGGLEITEM)
-		toolbar_toplevel_item_set_toggle_state_internal (uih, internal, internal->active);
+		toolbar_toplevel_item_set_toggle_state_internal (uih, internal, FALSE);
 	else if (internal->item->type == BONOBO_UI_HANDLER_TOOLBAR_RADIOITEM)
-		toolbar_toplevel_item_set_radio_state_internal (uih, internal, internal->active);
+		toolbar_toplevel_item_set_radio_state_internal (uih, internal, FALSE);
 }
 
 static void
@@ -2301,29 +2345,15 @@ toolbar_item_remote_get_pos (BonoboUIHandler *uih, const char *path)
 	return ans;
 }
 
-int
-bonobo_ui_handler_toolbar_item_get_pos (BonoboUIHandler *uih, const char *path)
-{
-	g_return_val_if_fail (uih != NULL, -1);
-	g_return_val_if_fail (BONOBO_IS_UI_HANDLER (uih), -1);
-	g_return_val_if_fail (path != NULL, -1);
-
-	if (uih->top_level_uih != CORBA_OBJECT_NIL)
-		return toolbar_item_remote_get_pos (uih, path);
-
-	return toolbar_toplevel_item_get_pos (uih, path);
-}
-
 static void
-toolbar_toplevel_set_sensitivity (BonoboUIHandler *uih, const char *name,
-				  gboolean sensitive)
+toolbar_toplevel_item_set_sensitivity (BonoboUIHandler *uih, const char *path, gboolean sensitive)
 {
-	ToolbarToolbarInternal *internal;
+	ToolbarItemInternal *internal;
 
-	internal = toolbar_toplevel_get_toolbar (uih, name);
+	internal = toolbar_toplevel_get_item (uih, path);
 	g_return_if_fail (internal != NULL);
 
-	toolbar_toplevel_set_sensitivity_internal (uih, internal, sensitive);
+	toolbar_toplevel_item_set_sensitivity_internal (uih, internal, sensitive);
 }
 
 static gboolean
@@ -2368,11 +2398,11 @@ bonobo_ui_handler_toolbar_item_set_sensitivity (BonoboUIHandler *uih, const char
 	if (uih->top_level_uih != CORBA_OBJECT_NIL)
 		toolbar_item_remote_set_sensitivity (uih, path, sensitive);
 	else
-		toolbar_toplevel_set_sensitivity (uih, path, sensitive);
+		toolbar_toplevel_item_set_sensitivity (uih, path, sensitive);
 }
 
 static gboolean
-toolbar_toplevel_get_sensitivity (BonoboUIHandler *uih, const char *path)
+toolbar_toplevel_item_get_sensitivity (BonoboUIHandler *uih, const char *path)
 {
 	ToolbarItemInternal *internal;
 
@@ -2382,6 +2412,18 @@ toolbar_toplevel_get_sensitivity (BonoboUIHandler *uih, const char *path)
 	return internal->sensitive;
 }
 
+static gboolean
+toolbar_toplevel_item_get_toggle_state (BonoboUIHandler *uih, const char *path)
+{
+	GtkWidget *widget;
+
+	widget = toolbar_toplevel_item_get_widget (uih, path);
+	g_return_val_if_fail (widget != NULL, FALSE);
+	g_return_val_if_fail (GTK_IS_TOGGLE_BUTTON (widget), FALSE);
+
+	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
+}
+
 void
 impl_Bonobo_UIHandler_toolbar_item_get_attributes (PortableServer_Servant   servant,
 						   const Bonobo_UIHandler   containee,
@@ -2413,10 +2455,20 @@ impl_Bonobo_UIHandler_toolbar_item_get_attributes (PortableServer_Servant   serv
 		return;
 	}
 
-	g_warning ("toolbar_get_attributes substantially unimplemented");
+	g_warning ("toolbar_item_get_attributes substantially unimplemented");
 
-	*pos       = toolbar_toplevel_item_get_pos (uih, (char *) path);
-	*sensitive = toolbar_toplevel_get_sensitivity (uih, path);
+	*pos             = toolbar_toplevel_item_get_pos (uih, (char *) path);
+	*sensitive       = toolbar_toplevel_item_get_sensitivity (uih, path);
+	*toggle_state    = toolbar_toplevel_item_get_toggle_state (uih, path);
+
+	/* FIXME.  The following is just to prevent uninitialized
+           memory accesses.  (And, specifically, to prevent the stub
+           from crashing if it tries to free the strings we are
+           supposed to return.)  */
+	*label           = CORBA_string_dup ("FIXME");
+	*hint            = CORBA_string_dup ("FIXME");
+	*accelerator_key = 0;
+	*ac_mods         = 0;
 }
 
 void
@@ -2450,7 +2502,8 @@ impl_Bonobo_UIHandler_toolbar_item_set_attributes (PortableServer_Servant  serva
 		return;
 	}
 
-	toolbar_toplevel_item_set_sensitivity_internal (uih, internal, sensitive);
+	toolbar_toplevel_item_set_sensitivity_internal  (uih, internal, sensitive);
+	toolbar_toplevel_item_set_toggle_state_internal (uih, internal, toggle_state);
 
 	g_warning ("toolbar_set_attributes substantially unimplemented");
 }
@@ -2809,7 +2862,7 @@ bonobo_ui_handler_toolbar_item_get_sensitivity (BonoboUIHandler *uih, const char
 	if (uih->top_level_uih != CORBA_OBJECT_NIL)
 		return toolbar_item_remote_get_sensitivity (uih, path);
 
-	return toolbar_toplevel_get_sensitivity (uih, path);
+	return toolbar_toplevel_item_get_sensitivity (uih, path);
 }
 
 void
@@ -2874,6 +2927,78 @@ bonobo_ui_handler_toolbar_item_get_callback (BonoboUIHandler *uih, const char *p
 	g_warning ("Unimplemented toolbar method");
 }
 
+static void
+toolbar_item_remote_set_state (BonoboUIHandler *uih, const char *path,
+			       gboolean state)
+{
+	UIRemoteAttributeData *attrs;
+	
+	attrs = toolbar_item_remote_attribute_data_get (uih, path);
+	if (!attrs)
+		return;
+	attrs->toggle_state = state;
+	toolbar_item_remote_attribute_data_set (uih, path, attrs);
+}
+
+
+static void
+toolbar_toplevel_item_set_state (BonoboUIHandler *uih, const char *path,
+				 gboolean state)
+{
+	ToolbarItemInternal *internal;
+
+	internal = toolbar_toplevel_get_item (uih, path);
+
+	g_return_if_fail (internal != NULL);
+
+	toolbar_toplevel_item_set_toggle_state_internal (uih, internal, state);
+}
+
+void
+bonobo_ui_handler_toolbar_item_toggle_set_state (BonoboUIHandler *uih, const char *path,
+						 gboolean state)
+{
+	g_return_if_fail (uih != NULL);
+	g_return_if_fail (BONOBO_IS_UI_HANDLER (uih));
+	g_return_if_fail (path != NULL);
+
+	if (uih->top_level_uih != CORBA_OBJECT_NIL) {
+		toolbar_item_remote_set_state (uih, path, state);
+		return;
+	}
+
+	toolbar_toplevel_item_set_state (uih, path, state);
+}
+
+static gboolean
+toolbar_item_remote_get_state (BonoboUIHandler *uih, const char *path)
+{
+	UIRemoteAttributeData *attrs;
+	gboolean ans;
+
+	attrs = toolbar_item_remote_attribute_data_get (uih, path);
+	if (!attrs)
+		return FALSE;
+
+	ans = (gboolean)attrs->toggle_state;
+
+	bonobo_ui_handler_remote_attribute_data_free (attrs);
+
+	return ans;
+}
+
+static gboolean
+toolbar_toplevel_item_get_state (BonoboUIHandler *uih, const char *path)
+{
+	ToolbarItemInternal *internal;
+
+	internal = toolbar_toplevel_get_item (uih, path);
+
+	g_return_val_if_fail (internal != NULL, -1);
+
+	return toolbar_toplevel_item_get_toggle_state_internal (uih, internal);
+}
+
 gboolean
 bonobo_ui_handler_toolbar_item_toggle_get_state (BonoboUIHandler *uih, const char *path)
 {
@@ -2881,19 +3006,10 @@ bonobo_ui_handler_toolbar_item_toggle_get_state (BonoboUIHandler *uih, const cha
 	g_return_val_if_fail (BONOBO_IS_UI_HANDLER (uih), FALSE);
 	g_return_val_if_fail (path != NULL, FALSE);
 
-	g_warning ("Unimplemented toolbar method");
-	return FALSE;
-}
+	if (uih->top_level_uih != CORBA_OBJECT_NIL)
+		return toolbar_item_remote_get_state (uih, path);
 
-void
-bonobo_ui_handler_toolbar_item_toggle_set_state (BonoboUIHandler *uih, const char *path,
-						gboolean state)
-{
-	g_return_if_fail (uih != NULL);
-	g_return_if_fail (BONOBO_IS_UI_HANDLER (uih));
-	g_return_if_fail (path != NULL);
-
-	g_warning ("Unimplemented toolbar method");
+	return toolbar_toplevel_item_get_state (uih, path);
 }
 
 gboolean
