@@ -151,7 +151,7 @@ create_persist_file_dialog_cb (GtkWidget *unused, BonoboObject *object)
 
 	persist = Bonobo_Unknown_query_interface (
 		bonobo_object_corba_objref (BONOBO_OBJECT (object)),
-		"IDL:GNOME/PersistStream:1.0", &ev);
+		"IDL:Bonobo/PersistStream:1.0", &ev);
 
         if (ev._major != CORBA_NO_EXCEPTION || !persist)
                 return;
@@ -202,7 +202,7 @@ add_object_to_container (char *server_goadid)
 	if (server == NULL)
 		return NULL;
 
-	view_frame = bonobo_client_site_new_view (client_site);
+	view_frame = bonobo_client_site_new_view (client_site, CORBA_OBJECT_NIL);
 	view_widget = bonobo_view_frame_get_wrapper (view_frame);
 
 	frame = gtk_frame_new (server_goadid);
@@ -226,7 +226,7 @@ add_object_to_container (char *server_goadid)
 			    (BonoboObject*) server);
 	
 	if (bonobo_object_client_has_interface (server,
-					       "IDL:GNOME/PersistStream:1.0",
+					       "IDL:Bonobo/PersistStream:1.0",
 					       NULL)) {
 		GtkWidget *button = gtk_button_new_with_label ("Load");
 		gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, FALSE, 0);
@@ -352,7 +352,7 @@ add_objects_to_menu (GnomeApp *app)
 	 * bonobo_object interface, add it to the menu */
 	for (i = 0; servers[i].repo_id; i++)
 	{
-		if (string_in_array ("IDL:GNOME/Embeddable:1.0",
+		if (string_in_array ("IDL:Bonobo/Embeddable:1.0",
 				     (const gchar**)servers[i].repo_id))
 		{
 			add_object_to_menu (app, &servers[i]);
