@@ -1,6 +1,6 @@
 #include <gnome.h>
 #include <libgnorba/gnorba.h>
-#include <bonobo/gnome-bonobo.h>
+#include <bonobo.h>
 
 #ifndef __BONOBO_AUDIO_ULAW_H__
 #define __BONOBO_AUDIO_ULAW_H__
@@ -9,14 +9,12 @@
  * Component data
  */
 typedef struct {
-  GnomeEmbeddable *embeddable;
+  BonoboEmbeddable *embeddable;
 
   gchar *sound;
   guint sound_len;
   
-  gint update_callback_id;
-  
-  GList *views;
+  gint update_callback_id;  
 } embeddable_data_t;
 
 /*
