@@ -289,7 +289,7 @@ bonobo_object_destroy_cb (BonoboEmbeddable *bonobo_object,
 	g_free (bonobo_object_data);
 
 	running_objects--;
-	if (running_objects != 0)
+	if (running_objects > 0)
 		return;
 
 	if (factory) {
@@ -449,11 +449,13 @@ create_view_menus (view_data_t *view_data)
 					label, NULL, -1, BONOBO_UI_HANDLER_PIXMAP_XPM_DATA,
 					bolt_xpm, 0, 0, clear_text_cb, view_data);
 
+	#if 0
 	bonobo_ui_handler_create_toolbar (uih, "Common");
 
 	bonobo_ui_handler_toolbar_new_item (uih, "/Common/item1", "item 1", NULL, -1,
 					   BONOBO_UI_HANDLER_PIXMAP_XPM_DATA, bolt_xpm,
 					   0, 0, NULL, NULL);
+	#endif
 }
 
 static void
@@ -732,6 +734,7 @@ view_factory (BonoboEmbeddable       *bonobo_object,
 	 * signals so that we can update the other views.
 	 */
 	gtk_text_set_editable (GTK_TEXT (view_data->text), TRUE);
+
 	gtk_signal_connect (GTK_OBJECT (view_data->text), "insert_text",
 			    GTK_SIGNAL_FUNC (text_inserted_cb), view_data);
 	gtk_signal_connect (GTK_OBJECT (view_data->text), "delete_text",
@@ -745,7 +748,6 @@ view_factory (BonoboEmbeddable       *bonobo_object,
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (view_data->sw),
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
-
 	gtk_container_add (GTK_CONTAINER (view_data->sw), view_data->text);
 
 	gtk_table_attach (GTK_TABLE (view_data->table), view_data->sw,
@@ -775,8 +777,6 @@ view_factory (BonoboEmbeddable       *bonobo_object,
         view = bonobo_view_new (view_data->table);
 	view_data->view = view;
 
-	bonobo_view_set_view_frame (view, view_frame);
-
 	gtk_signal_connect (GTK_OBJECT (view), "destroy",
 			    GTK_SIGNAL_FUNC (view_destroy_cb), view_data);
 
@@ -885,8 +885,7 @@ init_server_factory (int argc, char **argv)
 		"bonobo-text-plain", VERSION,
 		&argc, argv, NULL, 0, NULL, GNORBA_INIT_SERVER_FUNC, &ev);
 
-	orb = gnome_CORBA_ORB ();
-	if (bonobo_init (orb, NULL, NULL) == FALSE)
+	if (bonobo_init (CORBA_OBJECT_NIL, CORBA_OBJECT_NIL, CORBA_OBJECT_NIL) == FALSE)
 		g_error (_("I could not initialize Bonobo"));
 
 	CORBA_exception_free (&ev);
