@@ -249,31 +249,15 @@ file_save_as_cb (GtkWidget *widget, BonoboUIHandler *uih)
 	g_free (name);
 }
 
-static void
-file_open_cb (GtkWidget *widget, BonoboUIHandler *uih)
+void
+file_open (Frame *frame, gchar *name)
 {
-	gchar *name;
-	const gchar *mime;
-	const gchar *bid;
+	const gchar *mime, *bid;
 	static gint menu_id = 0;
-	Frame *frame;
 	Buffer *buffer;
 	BonoboViewFrame *view_frame;
 	gint pos = -1;
 
-	g_return_if_fail(uih != NULL);
-	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
-
-	if (!(frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih))))) {
-		g_warning ("unable to get active frame");
-		return;
-	}
-	
-	name = strdup(gtk_file_selection_get_filename(app.fs));
-	gtk_widget_destroy (GTK_WIDGET(app.fs));
-	app.fs = NULL;
-	if (!name) return;
-
 	if (!g_file_test(name, G_FILE_TEST_ISFILE)) return;
 	
 	if (!(mime = gnome_mime_type_of_file (name))) {
@@ -300,10 +284,10 @@ file_open_cb (GtkWidget *widget, BonoboUIHandler *uih)
 	}
 
 	if (bonobo_object_has_interface(BONOBO_OBJECT (buffer->server), 
-				       "IDL:Bonobo/PersistFile:1.0")) {
+					"IDL:Bonobo/PersistFile:1.0")) {
 		buffer_load_pf (buffer, name);
 	} else if (bonobo_object_has_interface(BONOBO_OBJECT (buffer->server), 
-					      "IDL:Bonobo/PersistStream:1.0")) {
+					       "IDL:Bonobo/PersistStream:1.0")) {
 		buffer_load_ps (buffer, name);
 	} else {
 		g_warning ("no storage interface found");
@@ -313,6 +297,28 @@ file_open_cb (GtkWidget *widget, BonoboUIHandler *uih)
 	update_buffer_menu ();
 }
 
+static void
+file_open_cb (GtkWidget *widget, BonoboUIHandler *uih)
+{
+	gchar *name;
+	Frame *frame;
+
+	g_return_if_fail(uih != NULL);
+	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
+
+	if (!(frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih))))) {
+		g_warning ("unable to get active frame");
+		return;
+	}
+	
+	name = strdup(gtk_file_selection_get_filename(app.fs));
+	gtk_widget_destroy (GTK_WIDGET(app.fs));
+	app.fs = NULL;
+	if (!name) return;
+
+	file_open(frame, name);
+}
+
 void  
 file_menu_open_cb (BonoboUIHandler *uih, void *data, char *path)
 {
