@@ -8,14 +8,14 @@
 EFSDir *root;
 gchar path[EFS_MAXPATHLEN];
 
-void
+static void
 prompt (void)
 {
 	fprintf (stdout, "efs:%s# ",path);
 	fflush (stdout);
 }
 
-const char *
+static const char *
 full_path (const char *name)
 {
 	static gchar buf[EFS_MAXPATHLEN];
@@ -28,7 +28,7 @@ full_path (const char *name)
 	return buf;
 }
 
-void
+static void
 stat_command ()
 {
 	EFSStat *stat;
@@ -45,7 +45,7 @@ stat_command ()
 	printf("Inodes:      %d\n",stat->inodes);
 }
 
-void
+static void
 ls_command ()
 {
 	EFSDir *dir;
@@ -69,7 +69,7 @@ ls_command ()
 	efs_dir_close (dir);
 }
 
-void
+static void
 mv_command ()
 {
 	const char* from = strtok (NULL, " \t\n");
@@ -89,7 +89,7 @@ mv_command ()
 	}
 }
 
-void
+static void
 rm_command ()
 {
 	const char* name;
@@ -109,7 +109,7 @@ rm_command ()
 
 }
 
-void
+static void
 mkdir_command ()
 {
 	const char* name;
@@ -129,7 +129,7 @@ mkdir_command ()
 	} else efs_dir_close (dir);
 }
 
-void
+static void
 cd_command ()
 {
 	EFSDir *dir;
@@ -171,7 +171,7 @@ cd_command ()
 	efs_dir_close (dir);
 }
 
-void
+static void
 help_command ()
 {
 	printf("Available commands:\n");
@@ -186,7 +186,7 @@ help_command ()
 	printf("help           print this screen\n");
 }
 
-void
+static void
 add_file_or_dir (gchar *name) 
 {
 	struct stat sb;
@@ -237,7 +237,8 @@ add_file_or_dir (gchar *name)
 
 	printf("add %s failed!\n",name);
 }
-void
+
+static void
 list_contents (EFSDir *dir)
 {
 	EFSDir *d;
@@ -259,7 +260,7 @@ list_contents (EFSDir *dir)
 	}
 }
 
-void 
+static void 
 print_usage()
 {
 	fprintf (stderr, "usage: efstool efs-file\n");
@@ -360,5 +361,3 @@ main(int argc, char *argv[])
 	return 0;
 }
 
-
-
